==> rD3plot_1.0.25.tgz: rD3plot/www/colorScales.js <==
var basicColors = {
  "black": "#000000", // black
  "white": "#ffffff", // white
  "darkGrey": "#777777", // dark grey
  "mediumGrey": "#c6c6c6", // medium grey
  "lightGrey": "#f5f5f5" // light grey
}

var categoryColors = [
  "#1f77b4", // blue
  "#ff7f0e", // orange
  "#2ca02c", // green
  "#e377c2", // pink
  "#d62728", // red
  "#bcbd22", // lime
  "#9467bd", // purple
  "#8c564b", // brown
  "#7f7f7f", // grey
  "#17becf", // cyan
  "#aec7e8", // light blue
  "#ffbb78", // light orange
  "#98df8a", // light green
  "#f7b6d2", // light pink
  "#ff9896", // light red
  "#dbdb8d", // light lime
  "#c5b0d5", // light purple
  "#c49c94", // light brown
  "#c7c7c7", // light grey
  "#9edae5" // light cyan
];

var colorScales = {
  "WhGn": ["#ffffff","#2ca02c"],
  "GnWh": ["#2ca02c","#ffffff"],
  "WhRd": ["#ffffff","#d62728"],
  "RdWh": ["#d62728","#ffffff"],
  "WhBk": ["#ffffff","#000000"],
  "BkWh": ["#000000","#ffffff"],
  "WhBu": ["#ffffff","#1f77b4"],
  "BuWh": ["#1f77b4","#ffffff"],
  "GnWhRd": ["#2ca02c","#ffffff","#d62728"],
  "RdWhGn": ["#d62728","#ffffff","#2ca02c"],
  "BkWhRd": ["#000000","#ffffff","#d62728"],
  "RdWhBk": ["#d62728","#ffffff","#000000"],
  "BuWhRd": ["#1f77b4","#ffffff","#d62728"],
  "RdWhBu": ["#d62728","#ffffff","#1f77b4"],
  "YlWhBu": ["#bcbd22","#ffffff","#1f77b4"],
  "BuWhYl": ["#1f77b4","#ffffff","#bcbd22"],
  "GnBkRd": ["#2ca02c","#000000","#d62728"],
  "RdBkGn": ["#d62728","#000000","#2ca02c"],
  "BkRd": ["#000000","#d62728"],
  "RdBk": ["#d62728","#000000"],
  "BuRd": ["#1f77b4","#d62728"],
  "RdBu": ["#d62728","#1f77b4"],
  "YlBu": ["#bcbd22","#1f77b4"],
  "BuYl": ["#1f77b4","#bcbd22"],
  "BuGn": ["#6720d6", "#0bd638"],
  "PiGn": ["#d6249d", "#70d661"],
  "YlPi": ["#d6c30c", "#8a013c"],
  "BuPi": ["#24d6c0", "#d618cc"],
  "OrPu": ["#d68706", "#811cd6"],
  "PiWh": ["#d618cc", "#ffffff"],
  "OrWh": ["#d68d01", "#ffffff"],
  "YlWh": ["#d6d31f", "#ffffff"]
};

==> rD3plot_1.1.21.tgz: rD3plot/www/colorScales.js <==
var basicColors = {
  "black": "#000000", // black
  "white": "#ffffff", // white
  "darkGrey": "#777777", // dark grey
  "mediumGrey": "#c6c6c6", // medium grey
  "lightGrey": "#f5f5f5", // light grey
  "darkBlue": "#135dcd", // dark blue
  "mediumBlue": "#2f7bee", // medium blue
  "lightBlue": "#cbdefb" // light blue
}

var categoryColors = [
  "#1f77b4", // blue
  "#ff7f0e", // orange
  "#2ca02c", // green
  "#e377c2", // pink
  "#d62728", // red
  "#bcbd22", // lime
  "#9467bd", // purple
  "#8c564b", // brown
  "#7f7f7f", // grey
  "#17becf", // cyan
  "#aec7e8", // light blue
  "#ffbb78", // light orange
  "#98df8a", // light green
  "#f7b6d2", // light pink
  "#ff9896", // light red
  "#dbdb8d", // light lime
  "#c5b0d5", // light purple
  "#c49c94", // light brown
  "#c7c7c7", // light grey
  "#9edae5" // light cyan
];

var colorScales = {
  "WhGn": ["#ffffff","#2ca02c"],
  "GnWh": ["#2ca02c","#ffffff"],
  "WhRd": ["#ffffff","#d62728"],
  "RdWh": ["#d62728","#ffffff"],
  "WhBk": ["#ffffff","#000000"],
  "BkWh": ["#000000","#ffffff"],
  "WhBu": ["#ffffff","#1f77b4"],
  "BuWh": ["#1f77b4","#ffffff"],
  "GnWhRd": ["#2ca02c","#ffffff","#d62728"],
  "RdWhGn": ["#d62728","#ffffff","#2ca02c"],
  "BkWhRd": ["#000000","#ffffff","#d62728"],
  "RdWhBk": ["#d62728","#ffffff","#000000"],
  "BuWhRd": ["#1f77b4","#ffffff","#d62728"],
  "RdWhBu": ["#d62728","#ffffff","#1f77b4"],
  "YlWhBu": ["#bcbd22","#ffffff","#1f77b4"],
  "BuWhYl": ["#1f77b4","#ffffff","#bcbd22"],
  "GnBkRd": ["#2ca02c","#000000","#d62728"],
  "RdBkGn": ["#d62728","#000000","#2ca02c"],
  "BkRd": ["#000000","#d62728"],
  "RdBk": ["#d62728","#000000"],
  "BuRd": ["#1f77b4","#d62728"],
  "RdBu": ["#d62728","#1f77b4"],
  "YlBu": ["#bcbd22","#1f77b4"],
  "BuYl": ["#1f77b4","#bcbd22"],
  "BuGn": ["#6720d6", "#0bd638"],
  "PiGn": ["#d6249d", "#70d661"],
  "YlPi": ["#d6c30c", "#8a013c"],
  "BuPi": ["#24d6c0", "#d618cc"],
  "OrPu": ["#d68706", "#811cd6"],
  "PiWh": ["#d618cc", "#ffffff"],
  "OrWh": ["#d68d01", "#ffffff"],
  "YlWh": ["#d6d31f", "#ffffff"]
};
